__version__ = "0.3.19"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = u'(HEAD detached at v0.3.19)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'f14bbae0d5335051a7e53c0312d056c08570e478'
__git_head_subject__ = u'Finished Release v0.3.19'
__git_head_message__ = u''
__git_dirty_diff__ = u''
__git_commit_date__ = '2018-04-22 12:31:18'
